@@ -132,13 +132,14 @@ var (
 		},
 	}
 
-	clusterDNS = openshiftapiv1.DNS{
+	testDNSResourceGroupName = "os4-common"
+	clusterDNS               = openshiftapiv1.DNS{
 		ObjectMeta: metav1.ObjectMeta{
 			Name: "cluster",
 		},
 		Spec: openshiftapiv1.DNSSpec{
 			PublicZone: &openshiftapiv1.DNSZone{
-				ID: "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/os4-common/providers/Microsoft.Network/dnszones/devcluster.openshift.com",
+				ID: "/subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/" + testDNSResourceGroupName + "/providers/Microsoft.Network/dnszones/devcluster.openshift.com",
 			},
 		},
 	}
